@@ -1,8 +1,8 @@
 package Liveman;
-use 5.008001;
+use 5.22.0;
 use common::sense;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use Term::ANSIColor qw/colored/;
 use File::Slurper qw/read_text write_text/;
@@ -391,7 +391,7 @@ sub transform {
 
     # Меняем версию:
     my ($version) = $markdown =~ /#[ \t]+VERSION\s+([\d\.]+)\s/;
-    $module =~ s!^(our \$VERSION = ")[^"]*(";)!$0.06$version$2!m if defined $version;
+    $module =~ s!^(our \$VERSION = ")[^"]*(";)!$0.07$version$2!m if defined $version;
     write_text $pm, $module;
 
     $self->{count}++;
